@@ -103,26 +103,32 @@ class Artifacts:
         self.entry_list: List[ArtifactEntry] = entry_list if entry_list else []
 
     # 해당 Artifacts의 파일을 다운로드 후에 key에 해당하는 객체를 찾아 객체로 복원해서 반환
-    def get(self, key: str = None) -> Union[str, Table, Image, Chart]:
+    def get(self, key: str = None) -> Union[str, Table, Image, Chart, list[Image]]:
         self.download()
-        try:
-            artifact_entry = next(item for item in self.entry_list if item.key == key)
-        except StopIteration as e:
+
+        artifact_entry_list = [item for item in self.entry_list if item.key == key]
+        if len(artifact_entry_list) == 0:
             raise Exception(f"Cannnot find Entry by Key: key=[{key}]")
 
-        if artifact_entry.type == "TABLE":
-            return Table.from_file(artifact_entry.local_path)
-        if artifact_entry.type == "IMAGE":
-            return Image(artifact_entry.local_path)
-        if artifact_entry.type == "CHART":
-            return Chart.from_file(artifact_entry.local_path)
+        if len(artifact_entry_list) == 1:
+            artifact_entry = artifact_entry_list[0]
+            if artifact_entry.type == "TABLE":
+                return Table.from_file(artifact_entry.local_path)
+            if artifact_entry.type == "IMAGE":
+                return Image(artifact_entry.local_path)
+            if artifact_entry.type == "CHART":
+                return Chart.from_file(artifact_entry.local_path)
+        else:
+            # 일단은 이미지만 array 형태로 반환
+            return [Image(item.local_path) for item in artifact_entry_list]
+
 
     # 해당 Artifact에 데이터를 추가하는 함수
     # obj 및 파일 내용이 추가되면 임시 파일로 저장후 path를 추가한다
     # 추가된 각 항목에 대해서 ArtifactEntry를 생성한 후 Artifact가 가진 ArtifactEntry list에 추가함
     # name: 아티펙트에 각 엔트리의 식별자로 기록될 이름
     # data: 아티펙트에 추가될 데이터( Table  | Image | chart | file name | directory path | reference url )
-    def add(self, data: Union[str, Table, Image, Chart], name: str = None) -> None:
+    def add(self, data: Union[str, Table, Image, Chart, list[Image]], name: str = None) -> None:
         if isinstance(data, str):
             # if data is file_path
             data = os.path.relpath(data)  # Convert any path to a relative path
@@ -155,6 +161,18 @@ class Artifacts:
             self.entry_list.append(
                 ArtifactEntry(path=data.get_path(name), local_path=local_path, size=size, digest=digest, status="ADD",
                               lfs_yn="", repo_tag="", type="CHART", metadata=data.to_json(name), key=name))
+        elif isinstance(data, list):
+            if all(isinstance(n, Image) for n in data):    #Image 객체 배열일 경우
+                assert_that(name).is_not_none()
+                for index, n in enumerate(data):
+                    local_path = n.local_path
+                    digest = n.get_digest()
+                    size = n.get_size()
+                    self.entry_list.append(
+                        ArtifactEntry(path=n.get_path(key_name=name, is_list=True, index=index), local_path=local_path, size=size, digest=digest,
+                                      status="ADD",
+                                      lfs_yn="", repo_tag="", type="IMAGE", metadata=n.to_json(key_name=name, is_list=True, index=index), key=name))
+
 
     def __add_file(self, data: Union[str], name: str = None, depth: int = 0) -> None:
         # data에 str가 들어오면 file 인지, dir 인지 reference url(http:// or s3:// ..) 인지 체크
